@@ -5,9 +5,9 @@ import torch
 import torch.nn as nn
 from torch.utils.hooks import RemovableHandle
 
-from torchsummary.formatting import FormattingOptions
-from torchsummary.layer_info import LayerInfo
-from torchsummary.model_statistics import ModelStatistics
+from .formatting import FormattingOptions
+from .layer_info import LayerInfo
+from .model_statistics import ModelStatistics
 
 # Some modules do the computation themselves using parameters
 # or the parameters of children. Treat these as layers.
@@ -25,6 +25,7 @@ def summary(
     col_width: int = 25,
     dtypes: Optional[List[Type[torch.Tensor]]] = None,
     batch_dim: int = 0,
+    device: torch.device = None,
     **kwargs: Any,
 ) -> ModelStatistics:
     """
@@ -46,7 +47,7 @@ def summary(
             0 (quiet): No output
             1 (default): Print model summary
             2 (verbose): Show weight and bias layers in full detail
-        col_names (List): columns to show in the output. Currently supported:
+        col_names (List): specify which columns to show in the output. Currently supported:
             ['output_size', 'num_params', 'kernel_size', 'mult_adds']
         col_width (int): width of each column
         dtypes (List or None): for multiple inputs or args, must specify the size of both inputs.
@@ -67,7 +68,7 @@ def summary(
         if dtypes is None:
             dtypes = [torch.FloatTensor] * len(input_data)
         input_size = get_correct_input_sizes(input_data)
-        x = get_input_tensor(input_size, batch_dim, dtypes)
+        x = get_input_tensor(input_size, batch_dim, dtypes, device)
 
     try:
         with torch.no_grad():
@@ -87,9 +88,10 @@ def summary(
     return results
 
 
-def get_input_tensor(input_size, batch_dim, dtypes):
+def get_input_tensor(input_size, batch_dim, dtypes, device):
     """ Get input_tensor with batch size 2 for use in model.forward() """
-    device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
+    if device is None:
+        device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
     x = []
     for size, dtype in zip(input_size, dtypes):
         # add batch_size of 2 for BatchNorm
